@@ -30,16 +30,23 @@ def to_csvs(json_bytes, save_csv_bytes, null='#NA'):
         gen.send(csv_writer.writerow(dict_data.values()).encode('utf-8'))
 
     def to_path(prefix):
-        components = re.findall(r'([^.]+)\.item', prefix)
-        return '.'.join([f'{component}[*]' for component in components])
+        return re.sub(r'([^.]+)\.item', r'\1[*]', prefix)
 
     def handle_start_map(prefix, value):
         open_maps[prefix] = {}
 
     def handle_end_map(prefix, value):
-        # parent, _, key = prefix.rpartition('.')
         key = prefix.rpartition('.item')[0].rpartition('.')[2]
         is_top_level = 'id' in open_maps[prefix]
+        is_sub_object = not prefix.endswith('.item')
+
+        # If a plain object, append to parent
+        if is_sub_object:
+            parent_prefix = prefix[:prefix.rfind('.')]
+            sub_object_key = prefix[prefix.rfind('.') + 1:]
+            parent = open_maps[parent_prefix]
+            for sub_value_key, value in open_maps[prefix].items():
+                parent[sub_object_key + '__' + sub_value_key] = value
 
         # IDs of parents so the user can do JOINs
         parent_id_dict = {
@@ -48,15 +55,15 @@ def to_csvs(json_bytes, save_csv_bytes, null='#NA'):
         }
 
         # ... and only save these for nested top level
-        if is_top_level and len(parent_ids) > 1:
+        if not is_sub_object and is_top_level and len(parent_ids) > 1:
             save(to_path(prefix) + '.id', parent_id_dict)
 
         # ... but if _not_ top level (i.e. no ID), save the IDs and other data
-        if not is_top_level and len(parent_ids):
+        if not is_sub_object and not is_top_level and len(parent_ids):
             save(to_path(prefix), {**parent_id_dict, **open_maps[prefix]})
 
         # ... and if top level, but not yet saved it, save it
-        if is_top_level and open_maps[prefix]['id'] not in top_level_saved[key]:
+        if not is_sub_object and is_top_level and open_maps[prefix]['id'] not in top_level_saved[key]:
             save(f'{key}[*]', open_maps[prefix])
             top_level_saved[key].add(open_maps[prefix]['id'])
 
